References
----------

.. [Bredikhin22]
   Bredikhin *et al.* (2022),
   *MUON: multimodal omics analysis framework*,
   Genome Biology https://doi.org/10.1186/s13059-021-02577-8.

.. [Hastie09]
   Hastie *et al.* (2009),
   *The Elements of Statistical Learning*,
   Springer https://web.stanford.edu/~hastie/ElemStatLearn/.

.. [Huber15]
   Huber *et al.* (2015),
   *Orchestrating high-throughput genomic analysis with Bioconductor*,
   Nature Methods https://doi.org/10.1038/nmeth.3252.

.. [Murphy12]
   Murphy (2012,
   *Machine Learning: A Probabilistic Perspective*,
   MIT Press https://mitpress.mit.edu/9780262018029/machine-learning/.

.. [Wolf18] Wolf *et al.* (2018),
   *Scanpy: large-scale single-cell gene expression data analysis*,
   Genome Biology https://doi.org/10.1186/s13059-017-1382-0.
